summaryrefslogtreecommitdiffstats
path: root/examples/qxembedexample.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/qxembedexample.py')
-rw-r--r--examples/qxembedexample.py54
1 files changed, 27 insertions, 27 deletions
diff --git a/examples/qxembedexample.py b/examples/qxembedexample.py
index 0e21631..ab33196 100644
--- a/examples/qxembedexample.py
+++ b/examples/qxembedexample.py
@@ -3,7 +3,7 @@
# Form implementation generated from reading ui file 'qxembedexample.ui'
#
# Created: Thu Apr 29 02:17:37 2004
# by: The PyQt User Interface Compiler (pyuic) 3.11
#
# WARNING! All changes made in this file will be lost!
@@ -11,61 +11,61 @@
from qt import *
-class QXEmbedExample(QWidget):
+class TQXEmbedExample(TQWidget):
def __init__(self,parent = None,name = None,fl = 0):
- QWidget.__init__(self,parent,name,fl)
+ TQWidget.__init__(self,parent,name,fl)
if not name:
- self.setName("QXEmbedExample")
+ self.setName("TQXEmbedExample")
- QXEmbedExampleLayout = QVBoxLayout(self,11,6,"QXEmbedExampleLayout")
+ TQXEmbedExampleLayout = TQVBoxLayout(self,11,6,"TQXEmbedExampleLayout")
- layout2 = QHBoxLayout(None,0,6,"layout2")
+ layout2 = TQHBoxLayout(None,0,6,"layout2")
self.appNameCombo = KComboBox(0,self,"appNameCombo")
- self.appNameCombo.setSizePolicy(QSizePolicy(QSizePolicy.Minimum,QSizePolicy.Fixed,0,0,self.appNameCombo.sizePolicy().hasHeightForWidth()))
+ self.appNameCombo.setSizePolicy(TQSizePolicy(TQSizePolicy.Minimum,TQSizePolicy.Fixed,0,0,self.appNameCombo.sizePolicy().hasHeightForWidth()))
layout2.addWidget(self.appNameCombo)
self.launchButton = KPushButton(self,"launchButton")
- self.launchButton.setSizePolicy(QSizePolicy(QSizePolicy.Minimum,QSizePolicy.Fixed,0,0,self.launchButton.sizePolicy().hasHeightForWidth()))
+ self.launchButton.setSizePolicy(TQSizePolicy(TQSizePolicy.Minimum,TQSizePolicy.Fixed,0,0,self.launchButton.sizePolicy().hasHeightForWidth()))
layout2.addWidget(self.launchButton)
- spacer1 = QSpacerItem(209,31,QSizePolicy.Expanding,QSizePolicy.Minimum)
+ spacer1 = TQSpacerItem(209,31,TQSizePolicy.Expanding,TQSizePolicy.Minimum)
layout2.addItem(spacer1)
- QXEmbedExampleLayout.addLayout(layout2)
+ TQXEmbedExampleLayout.addLayout(layout2)
- self.line1 = QFrame(self,"line1")
- self.line1.setFrameShape(QFrame.HLine)
- self.line1.setFrameShadow(QFrame.Sunken)
- self.line1.setFrameShape(QFrame.HLine)
- QXEmbedExampleLayout.addWidget(self.line1)
+ self.line1 = TQFrame(self,"line1")
+ self.line1.setFrameShape(TQFrame.HLine)
+ self.line1.setFrameShadow(TQFrame.Sunken)
+ self.line1.setFrameShape(TQFrame.HLine)
+ TQXEmbedExampleLayout.addWidget(self.line1)
- self.mainTabs = QTabWidget(self,"mainTabs")
+ self.mainTabs = TQTabWidget(self,"mainTabs")
- self.tab = QWidget(self.mainTabs,"tab")
- tabLayout = QHBoxLayout(self.tab,11,6,"tabLayout")
+ self.tab = TQWidget(self.mainTabs,"tab")
+ tabLayout = TQHBoxLayout(self.tab,11,6,"tabLayout")
- self.textLabel1 = QLabel(self.tab,"textLabel1")
+ self.textLabel1 = TQLabel(self.tab,"textLabel1")
tabLayout.addWidget(self.textLabel1)
- self.mainTabs.insertTab(self.tab,QString(""))
- QXEmbedExampleLayout.addWidget(self.mainTabs)
+ self.mainTabs.insertTab(self.tab,TQString(""))
+ TQXEmbedExampleLayout.addWidget(self.mainTabs)
self.languageChange()
- self.resize(QSize(471,499).expandedTo(self.minimumSizeHint()))
- self.clearWState(Qt.WState_Polished)
+ self.resize(TQSize(471,499).expandedTo(self.minimumSizeHint()))
+ self.clearWState(TQt.WState_Polished)
self.connect(self.launchButton,SIGNAL("clicked()"),self.launchApp)
def languageChange(self):
- self.setCaption(self.__tr("QXEmbed Example"))
+ self.setCaption(self.__tr("TQXEmbed Example"))
self.appNameCombo.clear()
self.appNameCombo.insertItem(self.__tr("kcalc"))
self.appNameCombo.insertItem(self.__tr("konqueror"))
self.appNameCombo.insertItem(self.__tr("kedit"))
self.launchButton.setText(self.__tr("Launch and Embed"))
- self.textLabel1.setText(self.__tr("<b>QXEmbed Example</b>\n"
+ self.textLabel1.setText(self.__tr("<b>TQXEmbed Example</b>\n"
"<br><br>\n"
"\n"
"Select one of the app names from the combo list, then launch it with the button. Two seconds after launch, the window for the new process will get added as a new tab."))
@@ -73,7 +73,7 @@ class QXEmbedExample(QWidget):
def launchApp(self):
- print "QXEmbedExample.launchApp(): Not implemented yet"
+ print "TQXEmbedExample.launchApp(): Not implemented yet"
def __tr(self,s,c = None):
- return qApp.translate("QXEmbedExample",s,c)
+ return qApp.translate("TQXEmbedExample",s,c)
@@ -3,7 +3,7 @@
#
# Created: Thu Apr 29 02:17:37 2004
-# by: The PyQt User Interface Compiler (pyuic) 3.11
+# by: The PyTQt User Interface Compiler (pyuic) 3.11
#
# WARNING! All changes made in this file will be lost!